#
# spec file for package libansilove
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2019-2022, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global sover   1
%global libname %{name}%{sover}
Name:           libansilove
Version:        1.4.1
Release:        1.4
Summary:        Library for converting ANSI, ASCII, and other formats to PNG
License:        BSD-2-Clause
Group:          Productivity/Graphics/Other
URL:            https://www.ansilove.org
#Git-Clone:     https://github.com/ansilove/libansilove.git
Source:         https://github.com/ansilove/libansilove/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 3.1
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gdlib)

%description
libansilove is a library to convert ANSi and artscene related file
formats into PNG images.

The following formats are supported:

- .ANS - ANSi (ANSI escape sequences: ANSI X3.64 standard)
- .PCB - PCBoard Bulletin Board System (BBS) own file format
- .BIN - Binary format (raw memory copy of text mode video memory)
- .ADF - Artworx format, supporting custom character sets and palettes
- .IDF - iCE Draw format, supporting custom character sets and palettes
- .TND - TundraDraw format, supporting 24-bit color mode
- .XB - The eXtended Binary XBin format, supporting custom character
        sets and palettes

%package -n %{libname}
Summary:        Library for converting ANSI, ASCII, and other formats to PNG
Group:          Productivity/Graphics/Other

%description -n %{libname}
This library contains shared code regarding the conversion of ANSI and
artscene related file formats into PNG images.

%package devel
Summary:        Library for converting ANSI, ASCII, and other formats to PNG
Group:          Productivity/Graphics/Other
Requires:       %{libname} = %{version}

%description devel
This library contains shared code regarding the conversion of ANSI and
artscene related file formats into PNG images.

This subpackage contains libraries and header files for developing
applications that want to make use of libansilove.

%prep
%setup -q

%build
%cmake
make %{?_smp_mflags}

%install
%cmake_install

# Only keep the shared library
rm %{buildroot}%{_libdir}/libansilove-static.a

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license LICENSE
%doc AUTHORS ChangeLog README.md
%{_libdir}/libansilove.so.%{sover}*

%files devel
%{_includedir}/ansilove.h
%{_libdir}/libansilove.so
%{_mandir}/man3/libansilove.3%{?ext_man}
%{_mandir}/man3/ansilove_*.3%{?ext_man}

%changelog
* Mon Jun  5 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 1.4.1
  * Sync embedded Spleen 8x16 version to Spleen 2.0.0 (this swap arrows at positions 1A and 1B)
- Update to 1.4.0
  * Add font data for Spleen 8x16, it now has full CP437 support
* Thu May  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.3.1
  * Increment pcboard_buffer by more than one element at a time
  * Fix XBin font memory leaks
* Fri Feb 11 2022 Martin Hauke <mardnh@gmx.de>
- Update to versino 1.2.9
  - Use CMAKE_C_STANDARD instead of hardcoding compiler flags.
  - Add missing <stdint.h> include.
* Sun Oct 25 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.8
  * Add LibFuzzer-based fuzzers for each supported format
  * Do not hardcode CMAKE_BUILD_TYPE to "Release" in CMakeLists.txt
  * Only enable FORTIFY_SOURCE level 2 for release builds
  * Add #ifdef __cplusplus extern "C" to allow calling library
    functions from C++
  * Constify input and output arguments of ansilove_loadfile() and
    ansilove_savefile()
* Thu Oct 22 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.7
  - Error out early with ANSILOVE_FORMAT_ERROR in case ctx->length
    is 0.
  - Initialize ansi_buffer and pcboard_buffer to NULL.
  - Refactor the IceDraw loader to use a state machine.
  - Check strndup() return value and error out on failed allocations
  - Add some file format integrity checks in the IceDraw loader.
  - Add range integrity checks for scale_factor values in the
    output() function.
  - Return error code directly if ctx->length is 0 in the ANSI and
    PCBoard loaders.
  - Add range integrity checks for columns value in relevant loaders
  - Add range integrity checks for bits value in relevant loaders
  - Add additional file format integrity check in the XBin loader
* Wed Sep 30 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.6
  * Introduce canvas' width/height variables and refactor canvas
    creation.
  * Refactor the ANSI loader to use a state machine.
  * Remove systematic filtering of Form Feed characters in Amiga mode
  * Correct values for TUNDRA_COLOR_FOREGROUND and
    TUNDRA_COLOR_BACKGROUND.
  * Switch to using reallocarray(3) in the ANSI and PCBoard loaders
  * Add a compat layer for systems which do not have reallocarray(3)
  * Refactor canvas allocation for retina output
  * Introduce the ANSILOVE_RANGE_ERROR macro, for values out of
    allowed range
  * Error gracefully if canvas' width or height is equal to zero
  * Remove an useless comparison in drawchar()
  * Add some file format integrity checks in the Tundra loader
  * Refactor error handling in several loaders
* Thu Sep 24 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.5
  * Add missing parentheses in an if statement in output()
  * Define CR, LF, TAB, SUB, and ESC macros only once
  * Refactor error handling in the PCBoard loader
  * Stop parsing for PCBoard cursor position sequences
  * Add bound checks for {back,fore}ground color values in the
    PCBoard loader
  * Fix default background and foreground colors in the PCBoard
    loader
  * Refactor the PCBoard loader to use a state machine
  * Refactor the Binary loader to use a state machine
  * Refactor the Artworx loader to use a state machine
  * Add some file format integrity checks in the XBin loader
* Sun Jun 21 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.4
  * Use size_t in for loops setting color palettes
  * Remove unneeded gdImageFill() call when using Workbench mode
  * Define _GNU_SOURCE in CMakeLists.txt to avoid cluttering
    source files
  * Use size_t type for variables used to loop over arrays
  * Separate RGB values for palettes, makes color allocation code
    more readable and efficient
  * Move ADF color mapping array to config.h
* Mon May 25 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.3
  * Call memset() to set all fontData struct fields to zero in
    all loaders
  * Refactor error handling in ansilove_savefile()
  * Add error handling for fwrite() in ansilove_savefile()
  * Fix includes in various source files
* Thu Apr 30 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.2
  * Refactor the output function, to allow combining DOS aspect
    ratio and Retina
  * Remove the im_ prefix for all gdImagePtr variables
  * Various README changes and improvements
* Tue Mar 17 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.1
  * Call memset() to set all fontData struct fields to zero
  * Use the ternary operator to simplify character attributes
    assignments
* Mon Feb 17 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.0
  * Correct section number in manual page.
  * Add initial manual pages for all library functions and file
    formats renders
  * Stop calculating columnMax in the PCBoard loader, it's unused
  * Add support for user-specified columns in the PCBoard loader
* Mon Jan 20 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.9
  * Remove unneeded gdImageColorAllocate calls in the ADF and IDF
    loaders
  * Reset background24 to 0 when encountering blink attribute in
    an SGR sequence, fixing the remaining rendering bugs for 24-bit
    ANSI artworks
* Sun Jan 19 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.8
  * Properly reset pcboard buffer when CLS is encountered
  * Use memcmp() instead of testing each character one by one in
    the PCB loader
  * Do not use background and foreground variables to handle 24-bit
    ANSI colors
  * Various improvements in the IDF loader
* Thu Dec 19 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.7
  * Rename the alSelectFont() function to select_font()
  * Only export symbols which are part of the public API
* Mon Nov 18 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.6
  * Use CMAKE_INSTALL_{LIB,INCLUDE}DIR instead of hardcoding
    directories.
  * Introduce a XBIN_PALETTE_LENGTH macro
  * Use XBIN_HEADER_LENGTH and XBIN_PALETTE_LENGTH macros instead
    of magic numbers
  * Add another format validation check (palette size) in the
    XBin loader
- Drop patch (fixed by upstream):
  * libansilove-libsuffix.patch
* Fri Oct 25 2019 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.1.5
